==> camel-core-model-3.11.0-sources.jar: org/apache/camel/model/language/Hl7TerserExpression.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.model.language;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;

import org.apache.camel.spi.Metadata;

/**
 * Get the value of an HL7 message field specified by terse location specification syntax.
 */
@Metadata(firstVersion = "2.11.0", label = "language,hl7", title = "HL7 Terser")
@XmlRootElement(name = "hl7terser")
@XmlAccessorType(XmlAccessType.FIELD)
public class Hl7TerserExpression extends ExpressionDefinition {

    public Hl7TerserExpression() {
    }

    public Hl7TerserExpression(String expression) {
        super(expression);
    }

    @Override
    public String getLanguage() {
        return "hl7terser";
    }
}

==> camel-core-model-3.18.1-sources.jar: org/apache/camel/model/language/Hl7TerserExpression.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.model.language;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;

import org.apache.camel.spi.Metadata;

/**
 * Get the value of a HL7 message field specified by terse location specification syntax.
 */
@Metadata(firstVersion = "2.11.0", label = "language,hl7", title = "HL7 Terser")
@XmlRootElement(name = "hl7terser")
@XmlAccessorType(XmlAccessType.FIELD)
public class Hl7TerserExpression extends ExpressionDefinition {

    public Hl7TerserExpression() {
    }

    public Hl7TerserExpression(String expression) {
        super(expression);
    }

    @Override
    public String getLanguage() {
        return "hl7terser";
    }
}
